==> openshift-model-miscellaneous-6.5.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageAzureFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageRegistryConfigStorageAzureFluentImpl<A extends ImageRegistryConfigStorageAzureFluent<A>> extends BaseFluent<A> implements ImageRegistryConfigStorageAzureFluent<A>{
  public ImageRegistryConfigStorageAzureFluentImpl() {
  }
  public ImageRegistryConfigStorageAzureFluentImpl(ImageRegistryConfigStorageAzure instance) {
    this.withAccountName(instance.getAccountName()); 
    this.withCloudName(instance.getCloudName()); 
    this.withContainer(instance.getContainer()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String accountName;
  private String cloudName;
  private String container;
  private Map<String,Object> additionalProperties;
  public String getAccountName() {
    return this.accountName;
  }
  public A withAccountName(String accountName) {
    this.accountName=accountName; return (A) this;
  }
  public Boolean hasAccountName() {
    return this.accountName != null;
  }
  public String getCloudName() {
    return this.cloudName;
  }
  public A withCloudName(String cloudName) {
    this.cloudName=cloudName; return (A) this;
  }
  public Boolean hasCloudName() {
    return this.cloudName != null;
  }
  public String getContainer() {
    return this.container;
  }
  public A withContainer(String container) {
    this.container=container; return (A) this;
  }
  public Boolean hasContainer() {
    return this.container != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ImageRegistryConfigStorageAzureFluentImpl that = (ImageRegistryConfigStorageAzureFluentImpl) o;
    if (accountName != null ? !accountName.equals(that.accountName) :that.accountName != null) return false;
    if (cloudName != null ? !cloudName.equals(that.cloudName) :that.cloudName != null) return false;
    if (container != null ? !container.equals(that.container) :that.container != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(accountName,  cloudName,  container,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (accountName != null) { sb.append("accountName:"); sb.append(accountName + ","); }
    if (cloudName != null) { sb.append("cloudName:"); sb.append(cloudName + ","); }
    if (container != null) { sb.append("container:"); sb.append(container + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> openshift-model-miscellaneous-6.7.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/imageregistry/operator/v1/ImageRegistryConfigStorageAzureFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.imageregistry.operator.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ImageRegistryConfigStorageAzureFluentImpl<A extends ImageRegistryConfigStorageAzureFluent<A>> extends BaseFluent<A> implements ImageRegistryConfigStorageAzureFluent<A>{
  public ImageRegistryConfigStorageAzureFluentImpl() {
  }
  public ImageRegistryConfigStorageAzureFluentImpl(ImageRegistryConfigStorageAzure instance) {
    if (instance != null) {
      this.withAccountName(instance.getAccountName());
      this.withCloudName(instance.getCloudName());
      this.withContainer(instance.getContainer());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String accountName;
  private String cloudName;
  private String container;
  private Map<String,Object> additionalProperties;
  public String getAccountName() {
    return this.accountName;
  }
  public A withAccountName(String accountName) {
    this.accountName=accountName; return (A) this;
  }
  public Boolean hasAccountName() {
    return this.accountName != null;
  }
  public String getCloudName() {
    return this.cloudName;
  }
  public A withCloudName(String cloudName) {
    this.cloudName=cloudName; return (A) this;
  }
  public Boolean hasCloudName() {
    return this.cloudName != null;
  }
  public String getContainer() {
    return this.container;
  }
  public A withContainer(String container) {
    this.container=container; return (A) this;
  }
  public Boolean hasContainer() {
    return this.container != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ImageRegistryConfigStorageAzureFluentImpl that = (ImageRegistryConfigStorageAzureFluentImpl) o;
    if (!java.util.Objects.equals(accountName, that.accountName)) return false;

    if (!java.util.Objects.equals(cloudName, that.cloudName)) return false;

    if (!java.util.Objects.equals(container, that.container)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(accountName,  cloudName,  container,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (accountName != null) { sb.append("accountName:"); sb.append(accountName + ","); }
    if (cloudName != null) { sb.append("cloudName:"); sb.append(cloudName + ","); }
    if (container != null) { sb.append("container:"); sb.append(container + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
